@@ -218,7 +218,8 @@ nlopt_result ccsa_quadratic_minimize(
      double *x, /* in: initial guess, out: minimizer */
      double *minf,
      nlopt_stopping *stop,
-     nlopt_opt dual_opt, int inner_maxeval, unsigned verbose)
+     nlopt_opt dual_opt, int inner_maxeval, unsigned verbose, double rho_init,
+	 const double *sigma_init)
 {
      nlopt_result ret = NLOPT_SUCCESS;
      double *xcur, rho, *sigma, *dfdx, *dfdx_cur, *xprev, *xprevprev, fcur;
@@ -322,14 +323,16 @@ nlopt_result ccsa_quadratic_minimize(
      }
 
      for (j = 0; j < n; ++j) {
-	  if (nlopt_isinf(ub[j]) || nlopt_isinf(lb[j]))
+	  if (sigma_init && sigma_init[j] > 0)
+	  	   sigma[j] = sigma_init[j];
+	  else if (nlopt_isinf(ub[j]) || nlopt_isinf(lb[j]))
 	       sigma[j] = 1.0; /* arbitrary default */
 	  else
 	       sigma[j] = 0.5 * (ub[j] - lb[j]);
      }
-     rho = 1.0;
+     rho = rho_init;
      for (i = 0; i < m; ++i) {
-	  rhoc[i] = 1.0;
+	  rhoc[i] = rho_init;
 	  dual_lb[i] = y[i] = 0.0;
 	  dual_ub[i] = HUGE_VAL;
      }
